@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -57,6 +57,11 @@ QString FilterClawsMail::localMailDirPath()
         QString errorMsg;
         int errorRow;
         int errorCol;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        if (!folderListFile.open(QIODevice::ReadOnly)) {
+            qCWarning(MAILIMPORTER_LOG) << "Impossible to open " << folderListFile.fileName();
+        }
+#endif
         if (!doc.setContent(&folderListFile, &errorMsg, &errorRow, &errorCol)) {
             qCDebug(MAILIMPORTER_LOG) << "Unable to load document.Parse error in line " << errorRow << ", col " << errorCol << ": " << errorMsg;
             return QString();
